Struct lapix::Canvas

source ·
pub struct Canvas<IMG> { /* private fields */ }
The canvas is the area where drawing can take place. Each layer has a canvas, and the canvas in turn holds an image internally to represent the drawing on it.

Implementations

source

impl<IMG: Bitmap> Canvas<IMG>

source

pub fn new(size: Size<i32>) -> Self

Create a new blank canvas with a specified size

source

pub fn inner(&self) -> &IMG

Get the inner image held by this canvas

source

pub fn size(&self) -> Size<i32>

Get the size of the canvas in pixels. This is the amount of pixels of the underlying image, not the real screen-size that the canvas takes up when displayed.

source

pub fn width(&self) -> i32

Get the width of the canvas in pixels (width of the underlying image, not real screen-size)

source

pub fn height(&self) -> i32

Get the height of the canvas in pixels (height of the underlying image)

source

pub fn rect(&self) -> Rect<i32>

Get the rectangle representing the canvas dimensions, starting from the origin at (0, 0).

source

pub fn bytes(&self) -> &[u8]

Get a representation of the inner image as a slice of bytes

source

pub fn is_in_bounds(&self, p: Point<i32>) -> bool

Check whether a point is inside the canvas

source

pub fn set_img(&mut self, img: IMG)

Set the image of the canvas with a predefined one

source

pub fn take_inner(&mut self) -> IMG

Take the inner image replacing it with a dummy empty one.

source

pub fn clear(&mut self) -> IMG

Set all pixels of the canvas to transparent

source

pub fn resize(&mut self, size: Size<i32>) -> IMG

Resize the canvas, keeping the content that is in bounds and in case of an increase in one of the dimensions, set new pixels to transparent.

source

pub fn pixel(&self, p: Point<i32>) -> Color

Get the color of a pixel in a certain position in the canvas

source

pub fn set_pixel( &mut self, p: Point<i32>, color: Color ) -> Option<(Point<i32>, Color)>

Set the color of a pixel in a certain position in the canvas. If there was an actual change, return the data needed for a reversal, that is, which point needs to be set to which color to reverse the action.

source

pub fn line( &mut self, p1: Point<i32>, p2: Point<i32>, color: Color ) -> Vec<(Point<i32>, Color)>

Draw a line between two points in the canvas with a certain color. Returns a set of reversals (points and the colors they need to be set to in order to reverse the action).

source

pub fn rectangle( &mut self, p1: Point<i32>, p2: Point<i32>, color: Color ) -> Vec<(Point<i32>, Color)>

Draw a rectangle (outline) between two points in the canvas with a certain color. Returns a set of reversals (points and the colors they need to be set to in order to reverse the action).

source

pub fn set_area( &mut self, area: Rect<i32>, color: Color ) -> Vec<(Point<i32>, Color)>

Set an area of the canvas (determined by a rectangle) to a certain color. Returns a set of reversals (points and colors they need to be set to in order to reverse the action).

source

pub fn paste_obj(&mut self, obj: &FreeImage<IMG>) -> Vec<(Point<i32>, Color)>

Paste a free image into the canvas, overriding the contents that existed below that area. Returns a set of reversals (points and colors they need to be set to in order to reverse the action).

source

pub fn bucket( &mut self, p: Point<i32>, color: Color ) -> Vec<(Point<i32>, Color)>

Paint an enclosed area with a certain color. Returns a set of reversals (points and colors they need to be set to in order to reverse the action).

source

pub fn img_from_area(&self, area: Rect<i32>) -> IMG

Get an image from a certain area of the canvas (determined by a rectangle).