pub struct LoadProject(pub fn(PathBuf) -> Vec<u8>);Expand description
Holds a function that takes a path as input and outputs the bytes of the project file found at that path.
Tuple Fields
0: fn(PathBuf) -> Vec<u8>Trait Implementations
Sourceimpl Clone for LoadProject
impl Clone for LoadProject
Sourceimpl Debug for LoadProject
impl Debug for LoadProject
Sourceimpl PartialEq for LoadProject
impl PartialEq for LoadProject